General Support Functionality
=============================

.. module:: babel.support

Babel ships a few general helpers that are not being used by Babel itself
but are useful in combination with functionality provided by it.

Convenience Helpers
-------------------

.. autoclass:: Format
   :members:

.. autoclass:: LazyProxy
   :members:

Gettext Support
---------------

.. autoclass:: Translations
   :members:
